@@ -11,12 +11,21 @@ from __future__ import absolute_import, division, print_function
 from structlog import dev, processors, stdlib, threadlocal
 from structlog._base import BoundLoggerBase
 from structlog._config import (
-    configure, configure_once, get_config, get_logger, getLogger,
-    is_configured, reset_defaults, wrap_logger
+    configure,
+    configure_once,
+    get_config,
+    get_logger,
+    getLogger,
+    is_configured,
+    reset_defaults,
+    wrap_logger,
 )
 from structlog._generic import BoundLogger
 from structlog._loggers import (
-    PrintLogger, PrintLoggerFactory, ReturnLogger, ReturnLoggerFactory
+    PrintLogger,
+    PrintLoggerFactory,
+    ReturnLogger,
+    ReturnLoggerFactory,
 )
 from structlog.exceptions import DropEvent
 
@@ -27,11 +36,11 @@ except ImportError:  # pragma: nocover
     twisted = None
 
 
-__version__ = "18.1.0"
+__version__ = "18.2.0"
 
 __title__ = "structlog"
 __description__ = "Structured Logging for Python"
-__uri__ = "http://www.structlog.org/"
+__uri__ = "https://www.structlog.org/"
 
 __author__ = "Hynek Schlawack"
 __email__ = "hs@ox.cx"
